pub async fn run_integrated_server_on_with_shutdown(
config: Config,
addr: SocketAddr,
shutdown: Shutdown,
runtime: Arc<BackendRuntime>,
) -> Result<()>Expand description
Run the integrated server with an externally provided shutdown signal.
This allows tests and external callers to control when the server shuts down.